"""
漂流瓶插件
"""
import random
from iamai.plugin import BasePlugin
from iamai.rule import rule
from iamai.typing import RuleContext

class BottlePlugin(BasePlugin):
    """漂流瓶插件"""
    
    def __init__(self, bot, config=None):
        super().__init__(bot, config)
        self.bottles = []
        self.max_bottles = self.get_config('max_bottles', 100)
    
    @rule(name="bottle_send", condition="event.fields.get('content', '').startswith('bottle')")
    async def send_bottle(self, ctx: RuleContext):
        """发送漂流瓶"""
        content = ctx.event.get_field('content', '')
        if content.startswith('bottle '):
            message = content[7:].strip()
            if message:
                # 添加到漂流瓶池
                bottle = {
                    'message': message,
                    'sender_id': ctx.event.get_field('user_id', 'unknown'),
                    'timestamp': ctx.event.timestamp
                }
                self.bottles.append(bottle)
                
                # 保持漂流瓶数量限制
                if len(self.bottles) > self.max_bottles:
                    self.bottles.pop(0)
                
                console_middleware = ctx.bot.middlewares.get('console')
                if console_middleware:
                    await console_middleware.send_message(
                        f"🌊 漂流瓶已投入大海: {message[:20]}{'...' if len(message) > 20 else ''}",
                        ctx.event.get_field('channel_id', 'console_channel')
                    )
    
    @rule(name="bottle_receive", condition="event.type == 'message'")
    async def receive_bottle(self, ctx: RuleContext):
        """随机接收漂流瓶"""
        if self.bottles and random.random() < 0.1:  # 10%概率收到漂流瓶
            bottle = random.choice(self.bottles)
            console_middleware = ctx.bot.middlewares.get('console')
            if console_middleware:
                await console_middleware.send_message(
                    f"🌊 收到漂流瓶: {bottle['message']}",
                    ctx.event.get_field('channel_id', 'console_channel')
                )
    
    @rule(name="bottle_stats", condition="event.fields.get('content', '').startswith('bottle_stats')")
    async def bottle_stats(self, ctx: RuleContext):
        """漂流瓶统计"""
        stats_text = f"🌊 漂流瓶统计: 池中共有 {len(self.bottles)} 个漂流瓶"
        console_middleware = ctx.bot.middlewares.get('console')
        if console_middleware:
            await console_middleware.send_message(
                stats_text,
                ctx.event.get_field('channel_id', 'console_channel')
            )



"""
iamai - 现代异步规则驱动机器人框架
"""

__version__ = "4.0.0"
__author__ = "iamai Team"
__description__ = "现代异步规则驱动机器人框架"

# 核心导入
from .bot import Bot
from .event import Event, MessageEvent, JoinEvent, LeaveEvent, ReadyEvent, ErrorEvent, CustomEvent
from .message import Message, ConsoleMessage, WebSocketMessage, HTTPMessage, MessageBuilder
from .rule import RuleEngine, RuleDefinition, rule, when_all, when_any, Conditions
from .plugin import Plugin, BasePlugin, PluginManager, PluginConfig
from .middleware import Middleware, MiddlewareConfig, MiddlewareRegistry, middleware_registry, register_middleware
from .config import Config, BotConfig, LoggerConfig, MiddlewareConfig as ConfigMiddlewareConfig, PluginConfig as ConfigPluginConfig
from .logger import get_logger, setup_logger
from .typing import (
    ConnectType, LogLevel, RuleCondition, RuleAction, RuleContext,
    EventType, ConfigDict, MiddlewareConfig as TypingMiddlewareConfig,
    PluginConfig as TypingPluginConfig
)

# 导出所有公共API
__all__ = [
    # 核心类
    "Bot",
    
    # 事件系统
    "Event", "MessageEvent", "JoinEvent", "LeaveEvent", "ReadyEvent", "ErrorEvent", "CustomEvent",
    
    # 消息系统
    "Message", "ConsoleMessage", "WebSocketMessage", "HTTPMessage", "MessageBuilder",
    
    # 规则引擎
    "RuleEngine", "RuleDefinition", "rule", "when_all", "when_any", "Conditions",
    
    # 插件系统
    "Plugin", "BasePlugin", "PluginManager", "PluginConfig",
    
    # 中间件系统
    "Middleware", "MiddlewareConfig", "MiddlewareRegistry", "middleware_registry", "register_middleware",
    
    # 配置系统
    "Config", "BotConfig", "LoggerConfig", "ConfigMiddlewareConfig", "ConfigPluginConfig",
    
    # 日志系统
    "get_logger", "setup_logger",
    
    # 类型注解
    "ConnectType", "LogLevel", "RuleCondition", "RuleAction", "RuleContext",
    "EventType", "ConfigDict", "TypingMiddlewareConfig", "TypingPluginConfig",
    
    # 版本信息
    "__version__", "__author__", "__description__"
]



"""
消息系统模块
"""
from typing import Any, Dict, Optional, List
from dataclasses import dataclass, field
import time
from .typing import Event

@dataclass
class Message:
    """消息基类"""
    content: str
    user_id: str
    channel_id: str
    platform: str
    raw_data: Any
    timestamp: float = field(default_factory=time.time)
    fields: Dict[str, Any] = field(default_factory=dict)
    message_id: Optional[str] = None
    
    def __post_init__(self):
        """初始化后处理"""
        if not self.fields:
            self.fields = {}
        if not self.message_id:
            self.message_id = f"{self.platform}_{self.user_id}_{self.timestamp}"
    
    def get_field(self, key: str, default: Any = None) -> Any:
        """获取字段值"""
        return self.fields.get(key, default)
    
    def set_field(self, key: str, value: Any) -> None:
        """设置字段值"""
        self.fields[key] = value
    
    def has_field(self, key: str) -> bool:
        """检查字段是否存在"""
        return key in self.fields
    
    def to_dict(self) -> Dict[str, Any]:
        """转换为字典"""
        return {
            'content': self.content,
            'user_id': self.user_id,
            'channel_id': self.channel_id,
            'platform': self.platform,
            'message_id': self.message_id,
            'timestamp': self.timestamp,
            'fields': self.fields,
            'raw_data': self.raw_data
        }
    
    def to_event(self) -> Event:
        """转换为消息事件"""
        from .event import MessageEvent
        return MessageEvent(
            type='message',
            platform=self.platform,
            raw_data=self.raw_data,
            message=self
        )

@dataclass
class ConsoleMessage(Message):
    """控制台消息"""
    user_name: str = "User"
    
    def __post_init__(self):
        super().__post_init__()
        self.platform = "console"
        self.fields['user_name'] = self.user_name

@dataclass
class WebSocketMessage(Message):
    """WebSocket消息"""
    session_id: str = ""
    
    def __post_init__(self):
        super().__post_init__()
        self.platform = "websocket"
        self.fields['session_id'] = self.session_id

@dataclass
class HTTPMessage(Message):
    """HTTP消息"""
    request_id: str = ""
    headers: Dict[str, str] = field(default_factory=dict)
    
    def __post_init__(self):
        super().__post_init__()
        self.platform = "http"
        self.fields['request_id'] = self.request_id
        self.fields['headers'] = self.headers

# 消息构建器
class MessageBuilder:
    """消息构建器"""
    
    @staticmethod
    def create_console_message(
        content: str,
        user_id: str = "console_user",
        channel_id: str = "console_channel",
        user_name: str = "User",
        **fields
    ) -> ConsoleMessage:
        """创建控制台消息"""
        msg = ConsoleMessage(
            content=content,
            user_id=user_id,
            channel_id=channel_id,
            platform="console",
            raw_data={"content": content, "user_id": user_id, "channel_id": channel_id},
            user_name=user_name
        )
        for key, value in fields.items():
            msg.set_field(key, value)
        return msg
    
    @staticmethod
    def create_websocket_message(
        content: str,
        user_id: str,
        channel_id: str,
        session_id: str,
        **fields
    ) -> WebSocketMessage:
        """创建WebSocket消息"""
        msg = WebSocketMessage(
            content=content,
            user_id=user_id,
            channel_id=channel_id,
            platform="websocket",
            raw_data={"content": content, "user_id": user_id, "channel_id": channel_id},
            session_id=session_id
        )
        for key, value in fields.items():
            msg.set_field(key, value)
        return msg
    
    @staticmethod
    def create_http_message(
        content: str,
        user_id: str,
        channel_id: str,
        request_id: str,
        headers: Optional[Dict[str, str]] = None,
        **fields
    ) -> HTTPMessage:
        """创建HTTP消息"""
        msg = HTTPMessage(
            content=content,
            user_id=user_id,
            channel_id=channel_id,
            platform="http",
            raw_data={"content": content, "user_id": user_id, "channel_id": channel_id},
            request_id=request_id,
            headers=headers or {}
        )
        for key, value in fields.items():
            msg.set_field(key, value)
        return msg



"""
最小化测试脚本
"""
import asyncio
import sys
from pathlib import Path

# 添加项目根目录到Python路径
project_root = Path(__file__).parent
sys.path.insert(0, str(project_root / "src"))

try:
    # 直接导入核心模块
    from iamai.bot import Bot
    from iamai.event import Event
    from iamai.message import MessageBuilder
    from iamai.rule import rule
    from iamai.typing import RuleContext
    
    # 简单的测试规则
    @rule(name="test_help")
    async def test_help(ctx: RuleContext):
        """测试帮助命令"""
        content = ctx.event.get_field('content', '')
        if content.startswith('help'):
            print("🤖 测试机器人正在运行!")
    
    @rule(name="test_ping")
    async def test_ping(ctx: RuleContext):
        """测试ping命令"""
        content = ctx.event.get_field('content', '')
        if content.startswith('ping'):
            print("🏓 Pong!")
    
    async def main():
        """主函数"""
        print("启动测试机器人...")
        
        # 创建机器人实例（使用默认配置）
        bot = Bot()
        
        # 添加规则
        bot.add_rule(test_help)
        bot.add_rule(test_ping)
        
        print("机器人已启动，输入 'help' 或 'ping' 测试")
        print("输入 'quit' 退出")
        
        # 简单的控制台循环
        while True:
            try:
                user_input = input("> ").strip()
                if user_input.lower() == 'quit':
                    break
                
                # 创建测试事件
                message = MessageBuilder.create_console_message(
                    content=user_input,
                    user_id="test_user",
                    channel_id="test_channel"
                )
                
                event = message.to_event()
                
                # 处理事件
                await bot.process_event(event)
                
            except KeyboardInterrupt:
                break
            except Exception as e:
                print(f"错误: {e}")
        
        print("测试完成")
    
    if __name__ == "__main__":
        asyncio.run(main())

except ImportError as e:
    print(f"导入错误: {e}")
    import traceback
    traceback.print_exc()
    print("请确保已安装所需的依赖包")



"""
机器人核心模块
"""
import asyncio
import importlib
from typing import Any, Dict, List, Optional, Type, Union
from pathlib import Path
import signal
import sys

from .event import Event
from .rule import RuleEngine, RuleDefinition
from .plugin import PluginManager, BasePlugin
from .middleware import Middleware, MiddlewareRegistry, middleware_registry
from .config import Config
from .logger import get_logger, setup_logger

logger = get_logger(__name__)

class Bot:
    """机器人核心类"""
    
    def __init__(self, config: Optional[Union[str, Path, Config]] = None):
        # 配置
        if isinstance(config, (str, Path)):
            self.config = Config(config)
        elif isinstance(config, Config):
            self.config = config
        else:
            self.config = Config()
        
        # 设置日志（只在第一次创建Bot实例时设置）
        if not hasattr(Bot, '_logger_initialized'):
            setup_logger(
                level=self.config.bot_config.log.level,
                log_file=self.config.bot_config.log.log_file,
                console=self.config.bot_config.log.console,
                format_string=self.config.bot_config.log.format_string
            )
            Bot._logger_initialized = True
        
        # 核心组件
        self.rule_engine = RuleEngine()
        self.plugin_manager = PluginManager(self)
        self.middlewares: Dict[str, Middleware] = {}
        self.running = False
        
        # 统计信息
        self.stats = {
            'events_processed': 0,
            'rules_executed': 0,
            'plugins_loaded': 0,
            'middlewares_active': 0,
            'uptime': 0
        }
        
        # 信号处理
        self._setup_signal_handlers()
        
        logger.info("机器人实例已创建")
    
    def _setup_signal_handlers(self) -> None:
        """设置信号处理器"""
        if sys.platform != "win32":
            loop = asyncio.get_event_loop()
            
            def signal_handler():
                logger.info("收到信号，准备关闭...")
                asyncio.create_task(self.stop())
            
            for sig in [signal.SIGTERM, signal.SIGINT]:
                loop.add_signal_handler(sig, signal_handler)
    
    async def start(self) -> None:
        """启动机器人"""
        if self.running:
            logger.warning("机器人已在运行")
            return
        
        logger.info("启动机器人...")
        
        try:
            # 加载插件
            await self._load_plugins()
            
            # 启动中间件
            await self._start_middlewares()
            
            self.running = True
            logger.info("机器人启动成功")
            
            # 启动统计任务
            asyncio.create_task(self._stats_task())
            
            # 保持运行
            await self._keep_alive()
            
        except Exception as e:
            logger.error(f"启动机器人失败: {e}")
            await self.stop()
            raise
    
    async def stop(self) -> None:
        """停止机器人"""
        if not self.running:
            return
        
        logger.info("停止机器人...")
        
        self.running = False
        
        try:
            # 停止中间件
            await self._stop_middlewares()
            
            # 卸载插件
            await self._unload_plugins()
            
            logger.info("机器人已停止")
            
        except Exception as e:
            logger.error(f"停止机器人时出错: {e}")
    
    async def _load_plugins(self) -> None:
        """加载插件"""
        logger.info("加载插件...")
        
        # 从配置的插件目录加载
        for plugin_dir in self.config.bot_config.plugin_dir:
            try:
                loaded_plugins = self.plugin_manager.load_plugins_from_dir(plugin_dir)
                if loaded_plugins:
                    logger.info(f"从 {plugin_dir} 加载了 {len(loaded_plugins)} 个插件")
            except FileNotFoundError as e:
                logger.error(f"插件目录加载失败: {e}")
                # 继续加载其他目录，不中断启动
        
        # 等待插件加载完成
        await asyncio.sleep(0.1)
        
        self.stats['plugins_loaded'] = len(self.plugin_manager.plugins)
        logger.info(f"总共加载了 {self.stats['plugins_loaded']} 个插件")
    
    async def _unload_plugins(self) -> None:
        """卸载插件"""
        logger.info("卸载插件...")
        
        for plugin_name in list(self.plugin_manager.plugins.keys()):
            await self.plugin_manager.unload_plugin(plugin_name)
    
    async def _start_middlewares(self) -> None:
        """启动中间件"""
        logger.info("启动中间件...")
        
        for middleware_name in self.config.bot_config.middlewares:
            try:
                await self._load_middleware(middleware_name)
            except Exception as e:
                logger.error(f"加载中间件 {middleware_name} 失败: {e}")
        
        # 启动所有中间件
        for middleware in self.middlewares.values():
            try:
                await middleware.start()
            except Exception as e:
                logger.error(f"启动中间件 {middleware.name} 失败: {e}")
        
        self.stats['middlewares_active'] = len(self.middlewares)
        logger.info(f"启动了 {self.stats['middlewares_active']} 个中间件")
    
    async def _stop_middlewares(self) -> None:
        """停止中间件"""
        logger.info("停止中间件...")
        
        for middleware in self.middlewares.values():
            try:
                await middleware.stop()
            except Exception as e:
                logger.error(f"停止中间件 {middleware.name} 失败: {e}")
        
        self.middlewares.clear()
    
    async def _load_middleware(self, middleware_name: str) -> None:
        """加载中间件"""
        try:
            # 从注册表获取中间件类
            middleware_class = middleware_registry.get(middleware_name)
            if not middleware_class:
                raise ImportError(f"找不到中间件: {middleware_name}")
            
            # 获取配置
            config_name = middleware_name.split('.')[-1]
            middleware_config = self.config.get_middleware_config(config_name)
            
            # 添加bot_name到配置中
            middleware_config['bot_name'] = self.config.bot_config.bot_name
            
            # 创建中间件配置对象
            from .middleware import MiddlewareConfig
            config_obj = MiddlewareConfig(**middleware_config)
            
            # 创建中间件实例
            middleware = middleware_class(
                name=config_name,
                config=config_obj,
                bot=self
            )
            
            self.middlewares[middleware.name] = middleware
            logger.info(f"中间件 {middleware_name} 加载成功")
            
        except Exception as e:
            logger.error(f"加载中间件 {middleware_name} 失败: {e}")
            raise
    
    async def process_event(self, event: Event, middleware: Optional[Middleware] = None) -> List[Any]:
        """处理事件"""
        if not self.running:
            return []
        
        self.stats['events_processed'] += 1
        
        try:
            # 插件钩子
            await self.plugin_manager.process_event(event)
            
            # 规则引擎处理
            results = await self.rule_engine.process_event(
                event, self, middleware
            )
            
            self.stats['rules_executed'] += len(results)
            
            # 标记事件已处理
            event.handled = True
            
            return results
            
        except Exception as e:
            logger.error(f"处理事件时出错: {e}")
            return []
    
    def add_rule(self, rule: Union[RuleDefinition, callable]) -> None:
        """添加规则"""
        if callable(rule):
            # 装饰器规则
            if hasattr(rule, '_rule_metadata'):
                metadata = rule._rule_metadata
                rule_def = RuleDefinition(
                    name=metadata['name'],
                    condition=metadata['condition'],
                    action=rule,
                    priority=metadata['priority'],
                    enabled=metadata['enabled'],
                    event_types=metadata['event_types']
                )
                self.rule_engine.add_rule(rule_def)
            else:
                # 简单函数规则
                rule_def = RuleDefinition(
                    name=rule.__name__,
                    condition="event.type == 'message'",
                    action=rule,
                    priority=0,
                    enabled=True
                )
                self.rule_engine.add_rule(rule_def)
        else:
            # RuleDefinition对象
            self.rule_engine.add_rule(rule)
    
    def load_plugin(self, plugin_class: Type['Plugin'], config: Optional[Dict[str, Any]] = None) -> bool:
        """加载插件（同步包装）"""
        return asyncio.create_task(self.plugin_manager.load_plugin(plugin_class, config))
    
    def load_plugins_from_dir(self, plugin_dir: str) -> List[str]:
        """从目录加载插件"""
        return self.plugin_manager.load_plugins_from_dir(plugin_dir)
    
    def get_plugin(self, plugin_name: str) -> Optional['Plugin']:
        """获取插件"""
        return self.plugin_manager.get_plugin(plugin_name)
    
    def get_all_rules(self) -> List[RuleDefinition]:
        """获取所有规则"""
        return self.rule_engine.get_rules()
    
    def get_stats(self) -> Dict[str, Any]:
        """获取统计信息"""
        import time
        uptime = time.time() - getattr(self, '_start_time', time.time())
        
        return {
            **self.stats,
            'uptime': uptime,
            'plugins': len(self.plugin_manager.plugins),
            'middlewares': len(self.middlewares),
            'rules': len(self.rule_engine.rules)
        }
    
    async def _keep_alive(self) -> None:
        """保持运行"""
        self._start_time = asyncio.get_event_loop().time()
        
        try:
            while self.running:
                await asyncio.sleep(1)
        except asyncio.CancelledError:
            pass
    
    async def _stats_task(self) -> None:
        """统计任务"""
        while self.running:
            await asyncio.sleep(60)  # 每分钟更新一次统计
            logger.debug(f"统计信息: {self.get_stats()}")
    
    async def run(self) -> None:
        """运行机器人"""
        try:
            await self.start()
        except KeyboardInterrupt:
            logger.info("收到中断信号")
        finally:
            await self.stop()



"""
配置系统模块
"""
from typing import Any, Dict, List, Optional, Union
from dataclasses import dataclass, field
from pathlib import Path
import toml
import json
import yaml
from .typing import ConnectType, LogLevel, ConfigDict
from .logger import get_logger

logger = get_logger(__name__)

@dataclass
class LoggerConfig:
    """日志配置"""
    level: LogLevel = "INFO"
    log_file: Optional[str] = None
    console: bool = True
    format_string: Optional[str] = None

@dataclass
class MiddlewareConfig:
    """中间件配置基类"""
    middleware_connect_type: ConnectType = "direct"
    enabled: bool = True

@dataclass
class WebSocketMiddlewareConfig(MiddlewareConfig):
    """WebSocket中间件配置"""
    middleware_connect_type: ConnectType = "ws"
    host: str = "127.0.0.1"
    port: int = 8080
    url: str = "/ws"
    auto_reconnect: bool = True
    reconnect_interval: int = 5

@dataclass
class PluginConfig:
    """插件配置基类"""
    enabled: bool = True
    priority: int = 0

@dataclass
class BotConfig:
    """机器人配置"""
    bot_name: str = "Bot"
    plugins: List[str] = field(default_factory=list)
    plugin_dir: List[str] = field(default_factory=lambda: ["plugins"])
    middlewares: List[str] = field(default_factory=lambda: ["iamai.middleware.console"])
    log: LoggerConfig = field(default_factory=LoggerConfig)
    hot_reload: bool = False
    debug: bool = False

class Config:
    """配置管理器"""
    
    def __init__(self, config_path: Optional[Union[str, Path]] = None):
        self.config_path = Path(config_path) if config_path else None
        self.bot_config = BotConfig()
        self.middleware_configs: Dict[str, Dict[str, Any]] = {}
        self.plugin_configs: Dict[str, Dict[str, Any]] = {}
        
        if self.config_path and self.config_path.exists():
            self.load_config()
    
    def load_config(self) -> None:
        """加载配置文件"""
        if not self.config_path or not self.config_path.exists():
            logger.warning("配置文件不存在")
            return
        
        try:
            if self.config_path.suffix == '.toml':
                self._load_toml()
            elif self.config_path.suffix == '.json':
                self._load_json()
            elif self.config_path.suffix in ['.yaml', '.yml']:
                self._load_yaml()
            else:
                logger.error(f"不支持的配置文件格式: {self.config_path.suffix}")
                return
            
            logger.info(f"成功加载配置文件: {self.config_path}")
        except Exception as e:
            logger.error(f"加载配置文件失败: {e}")
    
    def _load_toml(self) -> None:
        """加载TOML配置"""
        with open(self.config_path, 'r', encoding='utf-8') as f:
            data = toml.load(f)
        self._parse_config_data(data)
    
    def _load_json(self) -> None:
        """加载JSON配置"""
        with open(self.config_path, 'r', encoding='utf-8') as f:
            data = json.load(f)
        self._parse_config_data(data)
    
    def _load_yaml(self) -> None:
        """加载YAML配置"""
        with open(self.config_path, 'r', encoding='utf-8') as f:
            data = yaml.safe_load(f)
        self._parse_config_data(data)
    
    def _parse_config_data(self, data: Dict[str, Any]) -> None:
        """解析配置数据"""
        # 解析bot配置
        if 'bot' in data:
            bot_data = data['bot']
            self.bot_config.bot_name = bot_data.get('bot_name', 'Bot')
            self.bot_config.plugins = bot_data.get('plugins', [])
            self.bot_config.plugin_dir = bot_data.get('plugin_dir', ['plugins'])
            self.bot_config.middlewares = bot_data.get('middlewares', ['iamai.middleware.console'])
            self.bot_config.hot_reload = bot_data.get('hot_reload', False)
            self.bot_config.debug = bot_data.get('debug', False)
            
            # 解析日志配置
            if 'log' in bot_data:
                log_data = bot_data['log']
                self.bot_config.log = LoggerConfig(
                    level=log_data.get('level', 'INFO'),
                    log_file=log_data.get('log_file'),
                    console=log_data.get('console', True),
                    format_string=log_data.get('format_string')
                )
        
        # 解析中间件配置
        if 'middleware' in data:
            for middleware_name, middleware_data in data['middleware'].items():
                self.middleware_configs[middleware_name] = middleware_data
        
        # 解析插件配置
        for key, value in data.items():
            if key not in ['bot', 'middleware']:
                self.plugin_configs[key] = value
    
    def get_middleware_config(self, middleware_name: str) -> Dict[str, Any]:
        """获取中间件配置"""
        return self.middleware_configs.get(middleware_name, {})
    
    def get_plugin_config(self, plugin_name: str) -> Dict[str, Any]:
        """获取插件配置"""
        return self.plugin_configs.get(plugin_name, {})
    
    def save_config(self) -> None:
        """保存配置"""
        if not self.config_path:
            logger.error("未指定配置文件路径")
            return
        
        data = {
            'bot': {
                'plugins': self.bot_config.plugins,
                'plugin_dir': self.bot_config.plugin_dir,
                'middlewares': self.bot_config.middlewares,
                'hot_reload': self.bot_config.hot_reload,
                'debug': self.bot_config.debug,
                'log': {
                    'level': self.bot_config.log.level,
                    'log_file': self.bot_config.log.log_file,
                    'console': self.bot_config.log.console,
                    'format_string': self.bot_config.log.format_string
                }
            },
            'middleware': self.middleware_configs,
            **self.plugin_configs
        }
        
        try:
            if self.config_path.suffix == '.toml':
                with open(self.config_path, 'w', encoding='utf-8') as f:
                    toml.dump(data, f)
            elif self.config_path.suffix == '.json':
                with open(self.config_path, 'w', encoding='utf-8') as f:
                    json.dump(data, f, indent=2, ensure_ascii=False)
            elif self.config_path.suffix in ['.yaml', '.yml']:
                with open(self.config_path, 'w', encoding='utf-8') as f:
                    yaml.dump(data, f, default_flow_style=False, allow_unicode=True)
            
            logger.info(f"成功保存配置文件: {self.config_path}")
        except Exception as e:
            logger.error(f"保存配置文件失败: {e}")

# 默认配置
def get_default_config() -> Config:
    """获取默认配置"""
    return Config()



"""
WebSocket中间件模块
"""
import asyncio
import json
from typing import Any, Dict, Optional
import websockets
from websockets.exceptions import ConnectionClosed, WebSocketException

from . import Middleware, register_middleware, MiddlewareConfig
from ..event import Event, MessageEvent
from ..message import Message, WebSocketMessage, MessageBuilder
from ..logger import get_logger
from ..config import WebSocketMiddlewareConfig

logger = get_logger(__name__)

@register_middleware("iamai.middleware.websocket")
class WebSocketMiddleware(Middleware):
    """WebSocket中间件"""
    
    def __init__(self, name: str, config: WebSocketMiddlewareConfig, bot: 'Bot'):
        super().__init__(name, config, bot)
        self.websocket: Optional[websockets.WebSocketServerProtocol] = None
        self.clients: Dict[str, websockets.WebSocketServerProtocol] = {}
        self.server: Optional[websockets.WebSocketServer] = None
    
    async def start(self) -> None:
        """启动中间件"""
        if not self.enabled:
            return
        
        logger.info(f"启动WebSocket中间件: {self.name}")
        
        if self.connect_type == "ws":
            await self.connect_ws()
        elif self.connect_type == "reverse_ws":
            await self.connect_reverse_ws()
        else:
            logger.error(f"不支持的连接类型: {self.connect_type}")
    
    async def stop(self) -> None:
        """停止中间件"""
        logger.info(f"停止WebSocket中间件: {self.name}")
        
        if self.server:
            self.server.close()
            await self.server.wait_closed()
        
        for client in self.clients.values():
            await client.close()
        
        self.connected = False
        logger.info("WebSocket中间件已停止")
    
    async def connect_ws(self) -> None:
        """WebSocket服务器连接"""
        try:
            self.server = await websockets.serve(
                self._handle_client,
                self.config.host,
                self.config.port
            )
            self.connected = True
            logger.info(f"WebSocket服务器已启动: ws://{self.config.host}:{self.config.port}")
        except Exception as e:
            logger.error(f"启动WebSocket服务器失败: {e}")
    
    async def connect_reverse_ws(self) -> None:
        """反向WebSocket连接"""
        try:
            uri = f"ws://{self.config.host}:{self.config.port}{self.config.url}"
            self.websocket = await websockets.connect(uri)
            self.connected = True
            logger.info(f"反向WebSocket已连接: {uri}")
            
            # 启动消息接收任务
            asyncio.create_task(self._receive_messages())
        except Exception as e:
            logger.error(f"反向WebSocket连接失败: {e}")
    
    async def _handle_client(self, websocket: websockets.WebSocketServerProtocol, path: str) -> None:
        """处理客户端连接"""
        client_id = f"{websocket.remote_address[0]}:{websocket.remote_address[1]}"
        self.clients[client_id] = websocket
        
        logger.info(f"新客户端连接: {client_id}")
        
        try:
            async for message in websocket:
                await self._process_message(message, client_id)
        except ConnectionClosed:
            logger.info(f"客户端断开连接: {client_id}")
        except Exception as e:
            logger.error(f"处理客户端消息时出错: {e}")
        finally:
            if client_id in self.clients:
                del self.clients[client_id]
    
    async def _receive_messages(self) -> None:
        """接收消息（反向WebSocket）"""
        if not self.websocket:
            return
        
        try:
            async for message in self.websocket:
                await self._process_message(message, "server")
        except ConnectionClosed:
            logger.info("反向WebSocket连接已关闭")
            if self.config.auto_reconnect:
                await self._reconnect()
        except Exception as e:
            logger.error(f"接收消息时出错: {e}")
    
    async def _process_message(self, message: str, client_id: str) -> None:
        """处理接收到的消息"""
        try:
            data = json.loads(message)
            
            # 创建消息对象
            ws_message = MessageBuilder.create_websocket_message(
                content=data.get('content', ''),
                user_id=data.get('user_id', client_id),
                channel_id=data.get('channel_id', 'default'),
                session_id=client_id,
                **data.get('fields', {})
            )
            
            # 创建事件
            event = ws_message.to_event()
            
            # 处理事件
            await self.handle_event(event)
            
        except json.JSONDecodeError:
            logger.error(f"无效的JSON消息: {message}")
        except Exception as e:
            logger.error(f"处理消息时出错: {e}")
    
    async def send_message(self, content: str, channel_id: str, **kwargs) -> None:
        """发送消息"""
        message_data = {
            'content': content,
            'channel_id': channel_id,
            'timestamp': asyncio.get_event_loop().time(),
            **kwargs
        }
        
        try:
            if self.connect_type == "ws":
                # 服务器模式：发送给所有客户端
                disconnected_clients = []
                for client_id, client in self.clients.items():
                    try:
                        await client.send(json.dumps(message_data))
                    except ConnectionClosed:
                        disconnected_clients.append(client_id)
                
                # 清理断开的客户端
                for client_id in disconnected_clients:
                    del self.clients[client_id]
            
            elif self.connect_type == "reverse_ws" and self.websocket:
                # 客户端模式：发送给服务器
                await self.websocket.send(json.dumps(message_data))
            
        except Exception as e:
            logger.error(f"发送消息时出错: {e}")
    
    async def _reconnect(self) -> None:
        """重新连接"""
        if not self.config.auto_reconnect:
            return
        
        logger.info("尝试重新连接...")
        
        for attempt in range(5):  # 最多重试5次
            try:
                await asyncio.sleep(self.config.reconnect_interval)
                await self.connect_reverse_ws()
                logger.info("重新连接成功")
                return
            except Exception as e:
                logger.warning(f"重连尝试 {attempt + 1} 失败: {e}")
        
        logger.error("重连失败，停止尝试")
    
    def create_event(self, raw_data: Any, **fields) -> Event:
        """创建事件"""
        if isinstance(raw_data, dict) and 'content' in raw_data:
            # 创建消息事件
            message = MessageBuilder.create_websocket_message(
                content=raw_data['content'],
                user_id=raw_data.get('user_id', 'unknown'),
                channel_id=raw_data.get('channel_id', 'default'),
                session_id=raw_data.get('session_id', ''),
                **fields
            )
            return message.to_event()
        else:
            # 创建通用事件
            return Event(
                type='custom',
                platform='websocket',
                raw_data=raw_data,
                **fields
            )
    
    async def disconnect(self) -> None:
        """断开连接"""
        if self.websocket:
            await self.websocket.close()
        
        for client in self.clients.values():
            await client.close()
        
        self.connected = False
        logger.info("WebSocket连接已断开")



"""
测试Textual界面
"""

import asyncio
import sys
from pathlib import Path

# 添加项目根目录到Python路径
project_root = Path(__file__).parent
sys.path.insert(0, str(project_root / "src"))

try:
    from iamai import Bot
    from iamai.rule import rule
    from iamai.typing import RuleContext

    # 测试规则
    @rule(name="help")
    async def help_rule(ctx: RuleContext):
        """帮助命令"""
        content = ctx.event.get_field("content", "")
        if content.startswith("help"):
            help_text = """
🤖 可用命令:
- help: 显示此帮助信息
- ping: 测试机器人响应
- echo <消息>: 回显消息
- time: 显示当前时间
- stats: 显示机器人统计信息
"""
            # 发送到控制台中间件
            console_middleware = ctx.bot.middlewares.get("console")
            if console_middleware:
                await console_middleware.send_message(
                    help_text.strip(),
                    ctx.event.get_field("channel_id", "console_channel"),
                )

    @rule(name="ping")
    async def ping_rule(ctx: RuleContext):
        """Ping命令"""
        content = ctx.event.get_field("content", "")
        if content.startswith("ping"):
            console_middleware = ctx.bot.middlewares.get("console")
            if console_middleware:
                await console_middleware.send_message(
                    "🏓 Pong!", ctx.event.get_field("channel_id", "console_channel")
                )

    @rule(name="echo")
    async def echo_rule(ctx: RuleContext):
        """Echo命令"""
        content = ctx.event.get_field("content", "")
        if content.startswith("echo "):
            message = content[5:].strip()
            if message:
                console_middleware = ctx.bot.middlewares.get("console")
                if console_middleware:
                    await console_middleware.send_message(
                        f"📢 {message}",
                        ctx.event.get_field("channel_id", "console_channel"),
                    )

    @rule(name="time")
    async def time_rule(ctx: RuleContext):
        """时间命令"""
        content = ctx.event.get_field("content", "")
        if content.startswith("time"):
            import datetime

            now = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
            console_middleware = ctx.bot.middlewares.get("console")
            if console_middleware:
                await console_middleware.send_message(
                    f"🕐 当前时间: {now}",
                    ctx.event.get_field("channel_id", "console_channel"),
                )

    @rule(name="stats")
    async def stats_rule(ctx: RuleContext):
        """统计命令"""
        content = ctx.event.get_field("content", "")
        if content.startswith("stats"):
            stats = ctx.bot.get_stats()
            stats_text = f"""📊 机器人统计:
- 运行时间: {stats['uptime']:.1f}秒
- 处理事件: {stats['events_processed']}个
- 执行规则: {stats['rules_executed']}次
- 加载插件: {stats['plugins']}个
- 活跃中间件: {stats['middlewares']}个"""

            console_middleware = ctx.bot.middlewares.get("console")
            if console_middleware:
                await console_middleware.send_message(
                    stats_text, ctx.event.get_field("channel_id", "console_channel")
                )

    async def main():
        """主函数"""
        print("启动Textual界面机器人...")

        # 创建机器人实例
        bot = Bot(config="./config.toml")

        # 添加规则
        bot.add_rule(help_rule)
        bot.add_rule(ping_rule)
        bot.add_rule(echo_rule)
        bot.add_rule(time_rule)
        bot.add_rule(stats_rule)

        # 启动机器人
        await bot.run()

    if __name__ == "__main__":
        asyncio.run(main())

except ImportError as e:
    print(f"导入错误: {e}")
    import traceback

    traceback.print_exc()
    print("请确保已安装所需的依赖包")



"""
控制台中间件模块
使用Textual实现交互式终端界面
"""
import asyncio
from typing import Any, Dict, Optional
from textual.app import App, ComposeResult
from textual.containers import Horizontal, Vertical, Container
from textual.widgets import Input, Button, Static, RichLog, Header, Footer
from textual.reactive import reactive
from rich.text import Text
from dataclasses import dataclass
from . import Middleware, register_middleware, MiddlewareConfig
from ..event import Event, MessageEvent
from ..message import Message, ConsoleMessage, MessageBuilder
from ..logger import get_logger

logger = get_logger(__name__)

@dataclass
class ConsoleMiddlewareConfig(MiddlewareConfig):
    middleware_connect_type: str = "direct"
    bot_name: str = "BOT"
    bot_id: str = "111"
    user_name: str = "USER"
    user_id: str = "222"

class ChatPanel(RichLog):
    def __init__(self, **kwargs):
        super().__init__(id="chat-log", wrap=True, max_lines=1000, **kwargs)
        self.messages = []
    def add_message(self, user: str, content: str, is_bot: bool = False):
        from datetime import datetime
        timestamp = datetime.now().strftime("%H:%M:%S")
        emoji = "🤖" if is_bot else "👤"
        style = "bold blue" if is_bot else "bold green"
        text = Text(f"{emoji} [{timestamp}] {user}: ", style=style)
        text.append(content, style="white")
        self.write(text)
        self.messages.append({"user": user, "content": content, "is_bot": is_bot, "timestamp": timestamp})
        self.scroll_end(animate=False)

class LogPanel(RichLog):
    def __init__(self, **kwargs):
        super().__init__(id="system-log", wrap=True, max_lines=1000, **kwargs)
    def add_log(self, level: str, message: str):
        from datetime import datetime
        timestamp = datetime.now().strftime("%H:%M:%S")
        level_config = {
            "DEBUG": {"color": "dim", "emoji": "🐛"},
            "INFO": {"color": "blue", "emoji": "ℹ️"},
            "WARNING": {"color": "yellow", "emoji": "⚠️"},
            "ERROR": {"color": "red", "emoji": "❌"},
            "CRITICAL": {"color": "bold red", "emoji": "💥"}
        }
        config = level_config.get(level, {"color": "white", "emoji": "📝"})
        text = Text(f"{config['emoji']} [{timestamp}] {level}: ", style=config['color'] + " bold")
        text.append(message, style="white")
        self.write(text)
        self.scroll_end(animate=False)

class ConsoleApp(App):
    CSS = """
    Horizontal { height: 100%; }
    .chat-panel { width: 60%; border: solid $primary; margin: 1; }
    .log-panel { width: 40%; border: solid $secondary; margin: 1; }
    .input-container { height: 3; margin: 1; }
    .send-button { width: 3; content-align: center middle; background: $primary; color: $surface; margin-left: 1; border: solid $primary; }
    .send-button:hover { background: $primary-darken-1; }
    Input { margin: 1; }
    #chat-log { height: 1fr; border: solid $surface; margin: 1; }
    #system-log { height: 1fr; border: solid $surface; margin: 1; }
    """
    BINDINGS = [ ("ctrl+k", "command_palette", "Command Palette") ]
    def __init__(self, middleware: 'ConsoleMiddleware'):
        super().__init__()
        self.middleware = middleware
        self.chat_panel: ChatPanel = ChatPanel()
        self.log_panel: LogPanel = LogPanel()
    def compose(self) -> ComposeResult:
        yield Header()
        yield Horizontal(
            Vertical(
                Static("💬 聊天室", id="chat-title"),
                self.chat_panel,
                Horizontal(
                    Input(placeholder="输入消息...", id="message-input"),
                    Button("📤", id="send-button", classes="send-button"),
                    classes="input-container"
                ),
                classes="chat-panel"
            ),
            Vertical(
                Static("📋 系统日志", id="log-title"),
                self.log_panel,
                classes="log-panel"
            )
        )
        yield Footer()
    def on_mount(self) -> None:
        self.chat_panel.add_message(
            self.middleware.config.bot_name,
            "机器人已启动，输入 help 查看可用命令",
            is_bot=True
        )
        # 系统日志示例
        self.log_panel.add_log("INFO", "机器人实例已创建")
        self.log_panel.add_log("INFO", "启动机器人...")
        self.log_panel.add_log("INFO", "加载插件...")
        self.log_panel.add_log("INFO", "总共加载了 0 个插件")
        self.log_panel.add_log("INFO", "启动中间件...")
        self.log_panel.add_log("INFO", f"中间件 {self.middleware.name} 加载成功")
        self.log_panel.add_log("INFO", f"启动控制台中间件: {self.middleware.name}")
        self.log_panel.add_log("INFO", "控制台中间件已启动")
        self.log_panel.add_log("INFO", "启动了 1 个中间件")
        self.log_panel.add_log("INFO", "机器人启动成功")
    def on_input_submitted(self, event: Input.Submitted) -> None:
        if event.input.id == "message-input":
            self._send_message(event.input)
    def on_button_pressed(self, event: Button.Pressed) -> None:
        if event.button.id == "send-button":
            input_widget = self.query_one("#message-input", Input)
            self._send_message(input_widget)
    def _send_message(self, input_widget: Input) -> None:
        content = input_widget.value.strip()
        if content:
            self.chat_panel.add_message(
                self.middleware.config.user_name,
                content,
                is_bot=False
            )
            asyncio.create_task(self.middleware._process_user_input(content))
            input_widget.value = ""

@register_middleware("iamai.middleware.console")
class ConsoleMiddleware(Middleware):
    def __init__(self, name: str, config: ConsoleMiddlewareConfig, bot: 'Bot'):
        super().__init__(name, config, bot)
        self.app: ConsoleApp = None
        self.input_task = None
    async def start(self) -> None:
        if not self.enabled:
            return
        logger.info(f"启动控制台中间件: {self.name}")
        self.app = ConsoleApp(self)
        self.input_task = asyncio.create_task(self._run_app())
        self.connected = True
        logger.info("控制台中间件已启动")
    async def stop(self) -> None:
        logger.info(f"停止控制台中间件: {self.name}")
        if self.input_task:
            self.input_task.cancel()
            try:
                await self.input_task
            except asyncio.CancelledError:
                pass
        self.connected = False
        logger.info("控制台中间件已停止")
    async def _run_app(self) -> None:
        try:
            await self.app.run_async()
        except Exception as e:
            logger.error(f"控制台应用运行错误: {e}")
    async def send_message(self, content: str, channel_id: str, **kwargs) -> None:
        if self.app and self.app.chat_panel:
            self.app.chat_panel.add_message(
                self.config.bot_name,
                content,
                is_bot=True
            )
    async def _process_user_input(self, content: str) -> None:
        try:
            message = MessageBuilder.create_console_message(
                content=content,
                user_id=self.config.user_id,
                channel_id="console_channel",
                user_name=self.config.user_name
            )
            event = message.to_event()
            await self.handle_event(event)
        except Exception as e:
            logger.error(f"处理用户输入时出错: {e}")
            if self.app and self.app.log_panel:
                self.app.log_panel.add_log("ERROR", f"处理消息时出错: {e}")
    def create_event(self, raw_data: Any, **fields) -> Event:
        if isinstance(raw_data, dict) and 'content' in raw_data:
            message = MessageBuilder.create_console_message(
                content=raw_data['content'],
                user_id=raw_data.get('user_id', self.config.user_id),
                channel_id=raw_data.get('channel_id', 'console_channel'),
                user_name=raw_data.get('user_name', self.config.user_name),
                **fields
            )
            return message.to_event()
        else:
            return Event(
                type='custom',
                platform='console',
                raw_data=raw_data,
                **fields
            )
    async def connect_direct(self) -> None:
        self.connected = True
        logger.info("控制台中间件已连接")
    def add_log(self, level: str, message: str) -> None:
        if self.app and self.app.log_panel:
            self.app.log_panel.add_log(level, message)



"""
日志系统模块
使用loguru提供统一的日志功能
"""
from loguru import logger
import sys
from typing import Optional
from .typing import LogLevel

# 移除默认的logger
logger.remove()

def setup_logger(
    level: LogLevel = "INFO",
    log_file: Optional[str] = "iamai.log",
    console: bool = False,
    format_string: Optional[str] = None
) -> None:
    """设置日志器"""
    if format_string is None:
        format_string = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> | <level>{level: <8}</level> | <cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>"
    # 控制台输出
    if console:
        logger.add(
            sys.stderr,
            format=format_string,
            level=level,
            colorize=True,
            backtrace=True,
            diagnose=True
        )
    # 文件输出
    if log_file:
        logger.add(
            log_file,
            format=format_string,
            level=level,
            rotation="1 day",
            retention="30 days",
            compression="zip",
            backtrace=True,
            diagnose=True
        )

def get_logger(name: str):
    """获取logger实例"""
    return logger.bind(name=name)

# 默认只写文件
setup_logger()




"""
插件系统模块
"""
from abc import ABC, abstractmethod
from typing import Any, Dict, List, Optional, Type, Callable
from dataclasses import dataclass, field
import asyncio
import importlib
import inspect
from pathlib import Path

from .typing import PluginConfig, Event
from .rule import RuleDefinition
from .rule import rule, RuleEngine
from .logger import get_logger
from .config import PluginConfig as BasePluginConfig

logger = get_logger(__name__)

class PluginConfig(BasePluginConfig):
    """插件配置"""
    def __init__(self, **kwargs):
        super().__init__()
        for key, value in kwargs.items():
            setattr(self, key, value)

class Plugin(ABC):
    """插件抽象基类"""
    
    def __init__(self, bot: 'Bot', config: Optional[Dict[str, Any]] = None):
        self.bot = bot
        self.config = config or {}
        self.name = self.__class__.__name__
        self.enabled = self.config.get('enabled', True)
        self.priority = self.config.get('priority', 0)
        self.rules: List[RuleDefinition] = []
        
        # 自动注册规则
        self._register_rules()
    
    @abstractmethod
    async def on_load(self) -> None:
        """插件加载时调用"""
        pass
    
    @abstractmethod
    async def on_unload(self) -> None:
        """插件卸载时调用"""
        pass
    
    async def on_event(self, event: Event) -> None:
        """事件处理钩子"""
        pass
    
    async def before_event(self, event: Event) -> None:
        """事件处理前钩子"""
        pass
    
    async def after_event(self, event: Event) -> None:
        """事件处理后钩子"""
        pass
    
    async def on_error(self, error: Exception) -> None:
        """错误处理钩子"""
        pass
    
    def get_config(self, key: str, default: Any = None) -> Any:
        """获取配置值"""
        return self.config.get(key, default)
    
    def set_config(self, key: str, value: Any) -> None:
        """设置配置值"""
        self.config[key] = value
    
    def add_rule(self, rule_def: RuleDefinition) -> None:
        """添加规则"""
        rule_def.plugin = self.name
        self.rules.append(rule_def)
        logger.debug(f"插件 {self.name} 添加规则: {rule_def.name}")
    
    def _register_rules(self) -> None:
        """自动注册规则"""
        for name, method in inspect.getmembers(self, predicate=inspect.ismethod):
            if hasattr(method, '_rule_metadata'):
                metadata = method._rule_metadata
                rule_def = RuleDefinition(
                    name=metadata['name'],
                    condition=metadata['condition'],
                    action=method,
                    priority=metadata['priority'],
                    enabled=metadata['enabled'],
                    plugin=self.name,
                    event_types=metadata['event_types']
                )
                self.add_rule(rule_def)

class PluginManager:
    """插件管理器"""
    
    def __init__(self, bot: 'Bot'):
        self.bot = bot
        self.plugins: Dict[str, Plugin] = {}
        self.plugin_dirs: List[Path] = []
    
    async def load_plugin(self, plugin_class: Type[Plugin], config: Optional[Dict[str, Any]] = None) -> bool:
        """加载插件"""
        try:
            plugin = plugin_class(self.bot, config)
            if plugin.name in self.plugins:
                logger.warning(f"插件 {plugin.name} 已存在，跳过加载")
                return False
            
            await plugin.on_load()
            
            # 注册规则
            for rule in plugin.rules:
                self.bot.rule_engine.add_rule(rule)
            
            self.plugins[plugin.name] = plugin
            logger.info(f"插件 {plugin.name} 加载成功")
            return True
            
        except Exception as e:
            logger.error(f"加载插件失败: {e}")
            return False
    
    async def unload_plugin(self, plugin_name: str) -> bool:
        """卸载插件"""
        if plugin_name not in self.plugins:
            logger.warning(f"插件 {plugin_name} 不存在")
            return False
        
        try:
            plugin = self.plugins[plugin_name]
            await plugin.on_unload()
            
            # 移除规则
            for rule in plugin.rules:
                self.bot.rule_engine.remove_rule(rule.name)
            
            del self.plugins[plugin_name]
            logger.info(f"插件 {plugin_name} 卸载成功")
            return True
            
        except Exception as e:
            logger.error(f"卸载插件失败: {e}")
            return False
    
    async def reload_plugin(self, plugin_class: Type[Plugin], config: Optional[Dict[str, Any]] = None) -> bool:
        """重新加载插件"""
        plugin_name = plugin_class.__name__
        
        # 先卸载
        if plugin_name in self.plugins:
            await self.unload_plugin(plugin_name)
        
        # 再加载
        return await self.load_plugin(plugin_class, config)
    
    def load_plugins_from_dir(self, plugin_dir: str) -> List[str]:
        """从目录加载插件"""
        plugin_dir_path = Path(plugin_dir)
        if not plugin_dir_path.exists():
            raise FileNotFoundError(f"插件目录不存在: {plugin_dir}")
        
        loaded_plugins = []
        
        for py_file in plugin_dir_path.glob("*.py"):
            if py_file.name.startswith("_"):
                continue
            
            try:
                module_name = py_file.stem
                spec = importlib.util.spec_from_file_location(module_name, py_file)
                module = importlib.util.module_from_spec(spec)
                spec.loader.exec_module(module)
                
                # 查找插件类
                for name, obj in inspect.getmembers(module):
                    if (inspect.isclass(obj) and 
                        issubclass(obj, Plugin) and 
                        obj != Plugin):
                        
                        plugin_name = obj.__name__
                        if plugin_name not in self.plugins:
                            # 获取插件配置
                            plugin_config = self.bot.config.get_plugin_config(plugin_name)
                            
                            # 异步加载插件
                            asyncio.create_task(self.load_plugin(obj, plugin_config))
                            loaded_plugins.append(plugin_name)
                
            except Exception as e:
                logger.error(f"加载插件文件 {py_file} 失败: {e}")
        
        return loaded_plugins
    
    def get_plugin(self, plugin_name: str) -> Optional[Plugin]:
        """获取插件"""
        return self.plugins.get(plugin_name)
    
    def get_all_plugins(self) -> Dict[str, Plugin]:
        """获取所有插件"""
        return self.plugins.copy()
    
    def list_plugins(self) -> List[str]:
        """列出插件名称"""
        return list(self.plugins.keys())
    
    async def process_event(self, event: Event) -> None:
        """处理事件（插件钩子）"""
        for plugin in self.plugins.values():
            if not plugin.enabled:
                continue
            
            try:
                await plugin.before_event(event)
                await plugin.on_event(event)
                await plugin.after_event(event)
            except Exception as e:
                logger.error(f"插件 {plugin.name} 处理事件时出错: {e}")
                await plugin.on_error(e)

# 插件装饰器
def plugin_config(**config):
    """插件配置装饰器"""
    def decorator(plugin_class: Type[Plugin]):
        plugin_class._default_config = config
        return plugin_class
    return decorator

# 示例插件基类
class BasePlugin(Plugin):
    """基础插件类"""
    
    async def on_load(self) -> None:
        """插件加载"""
        logger.info(f"插件 {self.name} 已加载")
    
    async def on_unload(self) -> None:
        """插件卸载"""
        logger.info(f"插件 {self.name} 已卸载")



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import os
import sys

if sys.version_info >= (3, 11):
    import tomllib
else:
    import tomli as tomllib

# DATA = None
# PYPROJECT = os.path.join("..", "..", "cargo.toml")
# with open(PYPROJECT, "r", encoding="utf8") as f:
#     pyproject = f.read()
#     DATA = tomllib.loads(pyproject)
# print(DATA)
# PROJECT_VERSION = DATA["package"]["version"]
# PROJECT_NAME = DATA["project"]["name"]
# AUTHOR_TABLE = DATA["project"]["authors"]
# AUTHORS = ",".join([f"{aut['name']}<{aut['email']}>" for aut in AUTHOR_TABLE])

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = "Comprehensive AI Toolkit"  # PROJECT_NAME
# release = PROJECT_VERSION
copyright = "2023-PRESENT, Retrofor Wut?"
author = "HsiangNianian"  # AUTHORS

html_title = "Comprehensive AI Toolkit"

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinx.ext.todo",
    "sphinx.ext.napoleon",
    "sphinx.ext.autosummary",
    "sphinx.ext.extlinks",
    "myst_parser",
    "sphinx_last_updated_by_git",
]

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
extlinks = {
    "issue": ("https://github.com/retrofor/iamai/%s", "issue %s"),
    "doc": ("https://iamai.is-a.dev/en/latest/%s", "pages/%s"),
}
source_suffix = {
    ".rst": "restructuredtext",
    ".txt": "markdown",
    ".md": "markdown",
}

locale_dirs = ["../locales/"]  # path is example but recommended.
gettext_compact = False  # optional.
gettext_uuid = True  # optional.
translation_progress_classes = True

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "furo"
html_static_path = ["../_static"]
html_logo = "https://cdn.jsdelivr.net/gh/retrofor/iamai@master/docs/_static/retro.png"
html_favicon = html_logo

html_css_files = [
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/fontawesome.min.css",
    "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/brands.min.css",
]

html_theme_options = {
    "announcement": "<em><a href='#'>playground</a> is still under construction now, welcome any <a href='./pages/development/contributing.html'>contribution</a>!</em>",
    "source_repository": "https://github.com/retrofor/iamai/",
    "source_branch": "master",
    "source_directory": "docs/source/",
    "footer_icons": [
        {
            "name": "GitHub",
            "url": "https://github.com/retrofor/iamai/",
            "html": "",
            "class": "fa-brands fa-github",
        },
        {
            "name": "Pypi",
            "url": "https://pypi.org/project/iamai/",
            "html": "",
            "class": "fa-brands fa-python",
        },
    ],
}

#
# The following code was added during an automated build on readthedocs.org
# It is auto created and injected for every build. The result is based on the
# conf.py.tmpl file found in the readthedocs.org codebase:
# https://github.com/rtfd/readthedocs.org/blob/main/readthedocs/doc_builder/templates/doc_builder/conf.py.tmpl
#
# Note: this file shouldn't rely on extra dependencies.

import sys  # noqa: E402
import os.path  # noqa: E402

# User's Sphinx configurations
language_user = globals().get("language", None)
latex_engine_user = globals().get("latex_engine", None)
latex_elements_user = globals().get("latex_elements", None)

# Remove this once xindy gets installed in Docker image and XINDYOPS
# env variable is supported
# https://github.com/rtfd/readthedocs-docker-images/pull/98
latex_use_xindy = False



"""
规则引擎模块
"""
from typing import Any, Dict, List, Optional, Callable, Union, Set
from dataclasses import dataclass, field
from abc import ABC, abstractmethod
import asyncio
import re
from functools import wraps
from .typing import RuleCondition, RuleAction, RuleContext, EventType, LogLevel
from .event import Event
from .logger import get_logger

logger = get_logger(__name__)

@dataclass
class RuleDefinition:
    """规则定义"""
    name: str
    condition: RuleCondition
    action: RuleAction
    priority: int = 0
    enabled: bool = True
    plugin: Optional[str] = None
    event_types: Set[EventType] = field(default_factory=set)
    
    def __post_init__(self):
        if not self.event_types:
            self.event_types = {'message'}

class RuleEngine:
    """规则引擎"""
    
    def __init__(self):
        self.rules: List[RuleDefinition] = []
        self.facts: Dict[str, Any] = {}
        self.contexts: List[RuleContext] = []
        
    def add_rule(self, rule: RuleDefinition) -> None:
        """添加规则"""
        self.rules.append(rule)
        # 按优先级排序
        self.rules.sort(key=lambda r: r.priority, reverse=True)
        logger.debug(f"添加规则: {rule.name}")
    
    def remove_rule(self, name: str) -> bool:
        """移除规则"""
        for i, rule in enumerate(self.rules):
            if rule.name == name:
                self.rules.pop(i)
                logger.debug(f"移除规则: {name}")
                return True
        return False
    
    def get_rules(self, plugin: Optional[str] = None) -> List[RuleDefinition]:
        """获取规则列表"""
        if plugin:
            return [rule for rule in self.rules if rule.plugin == plugin]
        return self.rules
    
    async def process_event(self, event: Event, bot: 'Bot', middleware: Optional['Middleware'] = None, plugin: Optional['Plugin'] = None) -> List[Any]:
        """处理事件"""
        results = []
        context = RuleContext(event=event, bot=bot, middleware=middleware, plugin=plugin, facts=self.facts)
        
        logger.debug(f"处理事件: {event.type}, 平台: {event.platform}")
        
        # 筛选匹配的规则
        matching_rules = []
        for rule in self.rules:
            if not rule.enabled:
                continue
            if event.type not in rule.event_types:
                continue
            if self._evaluate_condition(rule.condition, context):
                matching_rules.append(rule)
        
        logger.debug(f"匹配到 {len(matching_rules)} 个规则")
        
        # 执行匹配的规则
        for rule in matching_rules:
            try:
                result = await self._execute_action(rule.action, context)
                if result is not None:
                    results.append(result)
                logger.debug(f"执行规则: {rule.name}")
            except Exception as e:
                logger.error(f"执行规则 {rule.name} 时出错: {e}")
        
        return results
    
    def _evaluate_condition(self, condition: RuleCondition, context: RuleContext) -> bool:
        """评估条件"""
        if isinstance(condition, str):
            return self._evaluate_string_condition(condition, context)
        elif callable(condition):
            try:
                return condition(context)
            except Exception as e:
                logger.error(f"条件评估错误: {e}")
                return False
        return False
    
    def _evaluate_string_condition(self, condition: str, context: RuleContext) -> bool:
        """评估字符串条件"""
        try:
            # 简单的条件表达式解析
            # 支持: event.type == "message", event.fields.get("content", "").startswith("help")
            
            # 替换变量
            condition = condition.replace("event.type", f"'{context.event.type}'")
            condition = condition.replace("event.platform", f"'{context.event.platform}'")
            
            # 处理 event.fields.get() 调用
            pattern = r'event\.fields\.get\(["\']([^"\']+)["\'][^)]*\)'
            def replace_fields(match):
                field_name = match.group(1)
                value = context.event.get_field(field_name, "")
                if isinstance(value, str):
                    return f"'{value}'"
                return str(value)
            
            condition = re.sub(pattern, replace_fields, condition)
            
            # 安全评估
            return eval(condition, {"__builtins__": {}}, {})
        except Exception as e:
            logger.error(f"字符串条件评估错误: {condition}, {e}")
            return False
    
    async def _execute_action(self, action: RuleAction, context: RuleContext) -> Any:
        """执行动作"""
        if asyncio.iscoroutinefunction(action):
            return await action(context)
        else:
            return action(context)
    
    def add_fact(self, key: str, value: Any) -> None:
        """添加事实"""
        self.facts[key] = value
        logger.debug(f"添加事实: {key} = {value}")
    
    def get_fact(self, key: str, default: Any = None) -> Any:
        """获取事实"""
        return self.facts.get(key, default)
    
    def remove_fact(self, key: str) -> bool:
        """移除事实"""
        if key in self.facts:
            del self.facts[key]
            logger.debug(f"移除事实: {key}")
            return True
        return False

# 规则装饰器
def rule(
    condition: Union[str, Callable] = "event.type == 'message'",
    priority: int = 0,
    event_types: Optional[List[EventType]] = None,
    name: Optional[str] = None,
    enabled: bool = True
):
    """规则装饰器"""
    def decorator(func):
        rule_name = name or func.__name__
        rule_event_types = set(event_types) if event_types else {'message'}
        
        @wraps(func)
        def wrapper(*args, **kwargs):
            return func(*args, **kwargs)
        
        # 添加规则元数据
        wrapper._rule_metadata = {
            'name': rule_name,
            'condition': condition,
            'priority': priority,
            'event_types': rule_event_types,
            'enabled': enabled,
            'action': func
        }
        
        return wrapper
    return decorator

def when_all(*conditions):
    """所有条件都满足"""
    def combined_condition(context: RuleContext) -> bool:
        for condition in conditions:
            if isinstance(condition, str):
                # 这里需要实现字符串条件的评估
                # 简化版本，实际应该更复杂
                if not eval(condition.replace("event", "context.event")):
                    return False
            elif callable(condition):
                if not condition(context):
                    return False
        return True
    return combined_condition

def when_any(*conditions):
    """任一条件满足"""
    def combined_condition(context: RuleContext) -> bool:
        for condition in conditions:
            if isinstance(condition, str):
                if eval(condition.replace("event", "context.event")):
                    return True
            elif callable(condition):
                if condition(context):
                    return True
        return False
    return combined_condition

# 预定义条件
class Conditions:
    """预定义条件"""
    
    @staticmethod
    def is_message(context: RuleContext) -> bool:
        """是消息事件"""
        return context.event.type == 'message'
    
    @staticmethod
    def is_join(context: RuleContext) -> bool:
        """是加入事件"""
        return context.event.type == 'join'
    
    @staticmethod
    def is_leave(context: RuleContext) -> bool:
        """是离开事件"""
        return context.event.type == 'leave'
    
    @staticmethod
    def content_starts_with(prefix: str):
        """内容以指定前缀开始"""
        def condition(context: RuleContext) -> bool:
            if context.event.type != 'message':
                return False
            content = context.event.get_field('content', '')
            return content.startswith(prefix)
        return condition
    
    @staticmethod
    def content_contains(text: str):
        """内容包含指定文本"""
        def condition(context: RuleContext) -> bool:
            if context.event.type != 'message':
                return False
            content = context.event.get_field('content', '')
            return text in content
        return condition
    
    @staticmethod
    def user_id_equals(user_id: str):
        """用户ID等于指定值"""
        def condition(context: RuleContext) -> bool:
            return context.event.get_field('user_id', '') == user_id
        return condition
    
    @staticmethod
    def platform_equals(platform: str):
        """平台等于指定值"""
        def condition(context: RuleContext) -> bool:
            return context.event.platform == platform
        return condition



"""
中间件系统模块
"""
from abc import ABC, abstractmethod
from typing import Any, Dict, Optional, Type, Union
from dataclasses import dataclass
import asyncio
from ..typing import ConnectType, MiddlewareConfig, Event
from ..logger import get_logger
from ..config import MiddlewareConfig as BaseMiddlewareConfig

logger = get_logger(__name__)

class MiddlewareConfig(BaseMiddlewareConfig):
    """中间件配置"""
    def __init__(self, **kwargs):
        super().__init__()
        for key, value in kwargs.items():
            setattr(self, key, value)

class Middleware(ABC):
    """中间件抽象基类"""
    
    def __init__(self, name: str, config: MiddlewareConfig, bot: 'Bot'):
        self.name = name
        self.config = config
        self.bot = bot
        self.connect_type = config.middleware_connect_type
        self.enabled = config.enabled
        self.connected = False
        
    @abstractmethod
    async def start(self) -> None:
        """启动中间件"""
        pass
    
    @abstractmethod
    async def stop(self) -> None:
        """停止中间件"""
        pass
    
    @abstractmethod
    async def send_message(self, content: str, channel_id: str, **kwargs) -> None:
        """发送消息"""
        pass
    
    @abstractmethod
    def create_event(self, raw_data: Any, **fields) -> Event:
        """创建事件"""
        pass
    
    # 网络连接方法（根据connect_type实现）
    async def connect_ws(self) -> None:
        """WebSocket连接"""
        raise NotImplementedError(f"中间件 {self.name} 不支持WebSocket连接")
    
    async def connect_reverse_ws(self) -> None:
        """反向WebSocket连接"""
        raise NotImplementedError(f"中间件 {self.name} 不支持反向WebSocket连接")
    
    async def connect_http(self) -> None:
        """HTTP连接"""
        raise NotImplementedError(f"中间件 {self.name} 不支持HTTP连接")
    
    async def connect_direct(self) -> None:
        """直接连接"""
        raise NotImplementedError(f"中间件 {self.name} 不支持直接连接")
    
    async def connect_polling(self) -> None:
        """轮询连接"""
        raise NotImplementedError(f"中间件 {self.name} 不支持轮询连接")
    
    async def disconnect(self) -> None:
        """断开连接"""
        self.connected = False
        logger.info(f"中间件 {self.name} 已断开连接")
    
    async def handle_event(self, event: Event) -> None:
        """处理事件"""
        if not self.enabled:
            return
        
        try:
            await self.bot.process_event(event, self)
        except Exception as e:
            logger.error(f"处理事件时出错: {e}")
    
    def is_connected(self) -> bool:
        """检查连接状态"""
        return self.connected
    
    def get_config_value(self, key: str, default: Any = None) -> Any:
        """获取配置值"""
        return getattr(self.config, key, default)

# 中间件注册表
class MiddlewareRegistry:
    """中间件注册表"""
    
    def __init__(self):
        self._middlewares: Dict[str, Type[Middleware]] = {}
    
    def register(self, name: str, middleware_class: Type[Middleware]) -> None:
        """注册中间件"""
        self._middlewares[name] = middleware_class
        logger.debug(f"注册中间件: {name}")
    
    def get(self, name: str) -> Optional[Type[Middleware]]:
        """获取中间件类"""
        return self._middlewares.get(name)
    
    def list_middlewares(self) -> Dict[str, Type[Middleware]]:
        """列出所有中间件"""
        return self._middlewares.copy()
    
    def create_middleware(self, name: str, config: MiddlewareConfig, bot: 'Bot') -> Optional[Middleware]:
        """创建中间件实例"""
        middleware_class = self.get(name)
        if middleware_class:
            return middleware_class(name, config, bot)
        return None

# 全局中间件注册表
middleware_registry = MiddlewareRegistry()

def register_middleware(name: str):
    """中间件注册装饰器"""
    def decorator(middleware_class: Type[Middleware]):
        middleware_registry.register(name, middleware_class)
        return middleware_class
    return decorator

# 导入所有中间件以确保注册
from . import console, websockets



"""
事件系统模块
"""
from typing import Any, Dict, Optional
from dataclasses import dataclass, field
import time
from .typing import EventType

@dataclass
class Event:
    """事件基类"""
    type: EventType
    platform: str
    raw_data: Any
    timestamp: float = field(default_factory=time.time)
    fields: Dict[str, Any] = field(default_factory=dict)
    handled: bool = False
    
    def __post_init__(self):
        """初始化后处理"""
        if not self.fields:
            self.fields = {}
    
    def get_field(self, key: str, default: Any = None) -> Any:
        """获取字段值"""
        return self.fields.get(key, default)
    
    def set_field(self, key: str, value: Any) -> None:
        """设置字段值"""
        self.fields[key] = value
    
    def has_field(self, key: str) -> bool:
        """检查字段是否存在"""
        return key in self.fields
    
    def to_dict(self) -> Dict[str, Any]:
        """转换为字典"""
        return {
            'type': self.type,
            'platform': self.platform,
            'timestamp': self.timestamp,
            'fields': self.fields,
            'handled': self.handled,
            'raw_data': self.raw_data
        }

@dataclass
class MessageEvent(Event):
    """消息事件"""
    message: 'Message' = None
    
    def __post_init__(self):
        super().__post_init__()
        self.type = 'message'

@dataclass
class JoinEvent(Event):
    """加入事件"""
    user_id: str = ""
    channel_id: str = ""
    
    def __post_init__(self):
        super().__post_init__()
        self.type = 'join'

@dataclass
class LeaveEvent(Event):
    """离开事件"""
    user_id: str = ""
    channel_id: str = ""
    
    def __post_init__(self):
        super().__post_init__()
        self.type = 'leave'

@dataclass
class ReadyEvent(Event):
    """就绪事件"""
    def __post_init__(self):
        super().__post_init__()
        self.type = 'ready'

@dataclass
class ErrorEvent(Event):
    """错误事件"""
    error: Exception = None
    error_msg: str = ""
    
    def __post_init__(self):
        super().__post_init__()
        self.type = 'error'

@dataclass
class CustomEvent(Event):
    """自定义事件"""
    event_name: str = ""
    
    def __post_init__(self):
        super().__post_init__()
        self.type = 'custom'



import nox

nox.options.sessions = ["test"]


@nox.session
def test(session: nox.Session):
    session.env["MATURIN_PEP517_ARGS"] = "--profile=dev"
    session.install(".[dev]")
    session.run("pytest")


@nox.session
def bench(session: nox.Session):
    session.env["MATURIN_PEP517_ARGS"] = "--profile=dev"
    session.install(".[dev]")
    session.run("pytest", "--benchmark-enable")



"""
漂流瓶示例 - 机器人启动脚本
"""
import asyncio
import sys
from pathlib import Path

# 添加项目根目录到Python路径
project_root = Path(__file__).parent.parent.parent
sys.path.insert(0, str(project_root / "src"))

from iamai import Bot
from iamai.rule import rule
from iamai.typing import RuleContext

# 基础规则
@rule(name="help", condition="event.fields.get('content', '').startswith('help')")
async def help_rule(ctx: RuleContext):
    """帮助命令"""
    help_text = """
🤖 可用命令:
- help: 显示此帮助信息
- ping: 测试机器人响应
- bottle <消息>: 发送漂流瓶
- bottle_stats: 查看漂流瓶统计
- stats: 显示机器人统计信息
"""
    console_middleware = ctx.bot.middlewares.get('console')
    if console_middleware:
        await console_middleware.send_message(
            help_text.strip(),
            ctx.event.get_field('channel_id', 'console_channel')
        )

@rule(name="ping", condition="event.fields.get('content', '').startswith('ping')")
async def ping_rule(ctx: RuleContext):
    """Ping命令"""
    console_middleware = ctx.bot.middlewares.get('console')
    if console_middleware:
        await console_middleware.send_message(
            "🏓 Pong!",
            ctx.event.get_field('channel_id', 'console_channel')
        )

@rule(name="stats", condition="event.fields.get('content', '').startswith('stats')")
async def stats_rule(ctx: RuleContext):
    """统计命令"""
    stats = ctx.bot.get_stats()
    stats_text = f"""📊 机器人统计:
- 运行时间: {stats['uptime']:.1f}秒
- 处理事件: {stats['events_processed']}个
- 执行规则: {stats['rules_executed']}次
- 加载插件: {stats['plugins']}个
- 活跃中间件: {stats['middlewares']}个"""
    
    console_middleware = ctx.bot.middlewares.get('console')
    if console_middleware:
        await console_middleware.send_message(
            stats_text,
            ctx.event.get_field('channel_id', 'console_channel')
        )

async def main():
    """主函数"""
    # 创建机器人实例
    bot = Bot(config="./config.toml")
    
    # 添加基础规则
    bot.add_rule(help_rule)
    bot.add_rule(ping_rule)
    bot.add_rule(stats_rule)
    
    # 启动机器人
    await bot.run()

if __name__ == "__main__":
    asyncio.run(main())



"""
类型注解定义模块
"""
from typing import Any, Dict, List, Optional, Union, Callable, Type, TypeVar, Generic, Awaitable, TYPE_CHECKING
from typing_extensions import Literal, TypedDict
from dataclasses import dataclass
from abc import ABC, abstractmethod

# 基础类型
T = TypeVar('T')
ConfigT = TypeVar('ConfigT')
EventT = TypeVar('EventT', bound='Event')
MessageT = TypeVar('MessageT', bound='Message')
MiddlewareT = TypeVar('MiddlewareT', bound='Middleware')
PluginT = TypeVar('PluginT', bound='Plugin')

# 网络连接类型
ConnectType = Literal["ws", "reverse_ws", "http", "direct", "polling"]

# 日志级别
LogLevel = Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]

# 规则条件类型
RuleCondition = Union[str, Callable[['RuleContext'], bool]]

# 规则动作类型
RuleAction = Union[Callable[['RuleContext'], Any], Callable[['RuleContext'], Awaitable[Any]]]

# 事件类型
EventType = Literal["message", "join", "leave", "ready", "error", "custom"]

# 配置字典类型
ConfigDict = Dict[str, Any]

# 中间件配置
class MiddlewareConfig(TypedDict, total=False):
    middleware_connect_type: ConnectType
    enabled: bool
    bot_name: str

# 插件配置
class PluginConfig(TypedDict, total=False):
    enabled: bool
    priority: int

# 规则上下文
@dataclass
class RuleContext:
    """规则执行上下文"""
    event: EventT
    bot: 'Bot'
    middleware: Optional[MiddlewareT] = None
    plugin: Optional[PluginT] = None
    facts: Dict[str, Any] = None
    
    def __post_init__(self):
        if self.facts is None:
            self.facts = {}

# 规则定义
# @dataclass
# class RuleDefinition:
#     """规则定义"""
#     name: str
#     condition: RuleCondition
#     action: RuleAction
#     priority: int = 0
#     enabled: bool = True
#     plugin: Optional[str] = None

# 抽象基类类型
class AbstractEvent(ABC):
    """事件抽象基类"""
    type: EventType
    timestamp: float
    platform: str
    raw_data: Any
    fields: Dict[str, Any]

class AbstractMessage(ABC):
    """消息抽象基类"""
    content: str
    user_id: str
    channel_id: str
    platform: str
    raw_data: Any
    fields: Dict[str, Any]

class AbstractMiddleware(ABC):
    """中间件抽象基类"""
    name: str
    config: MiddlewareConfig
    bot: 'Bot'
    connect_type: ConnectType

class AbstractPlugin(ABC):
    """插件抽象基类"""
    name: str
    config: PluginConfig
    bot: 'Bot'
    enabled: bool

# 为了向后兼容，导出Event类型
if TYPE_CHECKING:
    from .event import Event as EventType
else:
    # 运行时导入
    try:
        from .event import Event
    except ImportError:
        Event = None

# 前向引用，避免循环导入
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from .event import Event
    from .message import Message
    from .plugin import Plugin
    from .bot import Bot
